ananke.estimation
=================

..
   Submodules
   ----------

ananke.estimation.automated\_if
-------------------------------

.. automodule:: ananke.estimation.automated_if
   :members:
   :undoc-members:
   :show-inheritance:

ananke.estimation.counterfactual\_mean
--------------------------------------

.. automodule:: ananke.estimation.counterfactual_mean
   :members:
   :undoc-members:
   :show-inheritance:

ananke.estimation.empirical\_plugin
-----------------------------------

.. automodule:: ananke.estimation.empirical_plugin
   :members:
   :undoc-members:
   :show-inheritance:

..
   Module contents
   ---------------

.. automodule:: ananke.estimation
   :members:
   :undoc-members:
   :show-inheritance:
